@@ -136,9 +136,6 @@ class IPCInterceptionAddon:
                 if event_type == "callback":
                     orig_flow = self.intercepted_flows.pop(flow_id)
                     orig_flow.set_state(flow_state)
-                    # Remove the taken flag from the flow if present, the flow by definition
-                    # isn't take()n anymore once it's been passed back to the proxy.
-                    orig_flow.metadata.pop("taken", None)
                 elif event_type == "replay":
                     flow: HTTPFlow = HTTPFlow.from_state(flow_state)
                     # mitmproxy won't replay intercepted flows, this is an old flow so
@@ -189,7 +186,10 @@ class IPCInterceptionAddon:
             flow.response.headers["Content-Encoding"] = "identity"
 
     def response(self, flow: HTTPFlow):
-        if flow.metadata["response_injected"]:
+        cap_data: typing.Optional[SerializedCapData] = flow.metadata.get("cap_data")
+        if flow.metadata["response_injected"] and cap_data and cap_data.asset_server_cap:
+            # Don't bother intercepting asset server requests where we injected a response.
+            # We don't want to log them and they don't need any more processing by user hooks.
             return
         self._queue_flow_interception("response", flow)
 
